{% extends "shopyo_base/main_base.html" %}

{% set active_page ='control panel' %}

{% block pagehead %}
<title>Dashboard</title>
<link rel="stylesheet" href="/static/fontawesome/css/all.css">
{% endblock %}

{% block content %}
  {% include 'shopyo_dashboard/nav.html' %}

  <div class="container-fluid py-4">
    <div class="row no-gutters d-flex flex-wrap">
      {% for info in all_info %}
          {% if all_info[info]['type'] == 'show'%}
            <div class="col-auto">
              {%if 'dashboard' in all_info[info]%}
                <a class="shopyo-link" href="{{all_info[info]['url_prefix'] + all_info[info]['dashboard']}}">
              {%else%}
                <a class="shopyo-link" href="{{all_info[info]['url_prefix']}}">
              {%endif%}
              <div class="shopyo-dashboard-card card-menu h-100">
                <div class="card-body text-center d-flex flex-column align-items-center justify-content-center">
                  <i class="card-menu-icon {{all_info[info]['fa-icon']}}"></i>
                  <div class="card-footer mt-auto">
                    {{all_info[info]['display_string']}}
                  </div>
                </div>
              </div>
            </a>
            </div>
          {% endif %}
      {% endfor %}
    </div>
  </div>
 {% endblock %}
